<center><img src="https://raw.githubusercontent.com/colav/colav.github.io/master/img/Logo.png"/></center>

# HunabKu dspace plugin 
This is a dspace plugin and provides data in json parsed from xml.

# Description
You can download information of DSpace from multiples institutions such as udea, univalle, uext, unaula.

# Installation

## Dependencies
You need the database of dspace, you can download it using [Oxomoc](https://github.com/colav/oxomoc)
It requires MongoDB.
by default it uses the database `oxomoc` and the collections `dspace_{instution}_records`

## Package
You can install this package using pip
`pip install hunabku_dspace`



# License
BSD-3-Clause License 

# Links
http://colav.udea.edu.co/



